'''
---stpip---
This file organises the command line interface

@R. Thomas
@Santiago, Chile
@2019
'''


##standard library
import argparse

#local import
from . import __info__ as info


def command_line(args):
    '''
    This function defines the command line interface of the program.

    Parameters
    -----------
    None

    Returns
    -------
    args    Namespace with arguments
    '''

    ##create parser object
    parser = argparse.ArgumentParser(description='A pepy.tech web scraping for pypi download stats, version %s, \
            Licence: GPL'%(info.__version__))

    parser.add_argument('package', help='file, or list of file separated by comas (no space)')

    ###optional arguments
    parser.add_argument('-w', help='if you just want the last week download counts' , action='store_true')
    parser.add_argument('-m', help='if you just want the last month download counts' , action='store_true')
    parser.add_argument('-t', help='if you just want download counts all time' , action='store_true')
    parser.add_argument('--version', help='Display the version of stpip', action='store_true')

    ##create a group of arguments that are mandatory
    return parser.parse_args(args)



'''
---stpip---
This file contains the code that display the results

@R. Thomas
@Santiago, Chile
@2019
'''


def indiv(number,  display_type, package):
    '''
    This function go scrap pepy.tech

    Parameters
    -----------
    number
            int, number of downloads
    display_type
            str, type of display
    package
            str, name of the package

    Returns
    -------
    '''

    url = 'https://pepy.tech/project/' + package

    print('\033[1m\n###############################################\033[0;0m')
    print('\033[1m      Download counts for %s \033[0;0m'%package)
    
    if display_type == 'total':
        print('\033[1m Total all time:' + '\033[94m %s\033[0;0m'%number)

    else:
        print('\033[1m Total last %s:'%display_type + '\033[94m %s\033[0;0m'%number)

    print('\033[1m--> visit %s \033[0;0m'%url) 
    print('\033[1m\033[91m##############################################\033\n[0;0m') 
 

def full(total, month, day, yest, yest_down, package):
    '''
    Display all the download informations

    Parameters
    ----------
    total
            int, total number of downloads, all time
    month
            int, number of downloads in last month
    day
            int, number of downloads in the last week

    pacakge
            int, name of the package

    '''
    if yest_down == '0 0 0':
        url = 'No package found on pepy.tech with name %s'%package

    else:
        url = 'visit https://pepy.tech/project/' + package
    print('\033[1m\n###############################################\033[0;0m')
    print('\033[1m      Download counts for %s \033[0;0m'%package)
    print('\033[1m Total all time:' + '\033[94m %s\033[0;0m'%total)
    print('\033[1m Total last month:' + '\033[94m %s\033[0;0m'%month)
    print('\033[1m Total last week:' + '\033[94m %s\033[0;0m'%day)
    print('\033[1m last day %s:'%yest + '\033[94m %s\033[0;0m'%yest_down)
    print('\033[1m--> %s \033[0;0m'%url) 
    print('\033[1m\033[91m##############################################\033\n[0;0m') 
    




#!/usr/bin/./python
# -*- coding: utf-8 -*-

'''
---stpip---

stpip is a program web scrapping the pepy.tech website that displays pepy statistics.

usage: stpip --help
'''


###Python standard library
import sys


###local imports
from . import cli
from . import __info__ as info
from . import scraping
from . import display

def main():
    '''
    This is the main function of the program.
    '''
    ###first we load the command line interface
    args = cli.command_line(sys.argv[1:])

    ###here we check if at least one argument was given:
    if not args.package and not args.version:
        print('\033[1m[stpip Error]> no argument passed ...exit\033[0;0m')
        sys.exit()

    
    if args.version:
        print('version %s, Author: %s'%(info.__version__, info.__credits__))
        sys.exit()

    if args.package:
        ###extract package names from CLI
        packs = args.package.split(',')

        if len(packs)>1:
            tot = 0

        ##and go scraping!
        for i in packs:
            total, month, day, yesterday, yest_down = scraping.scrap(i)
            
            if len(packs)>1:
                tot += int(total) 

            if not args.t and not args.m and not args.w:
                display.full(total, month, day, yesterday, yest_down, i)

            elif args.t:
                display.indiv(total, 'total', i)

            elif args.m:
                display.indiv(month, 'month', i)

            elif args.w:
                display.indiv(day, 'week', i)

        if len(packs)>1:
            print('\033[1mTotal for all requested packages: %s Downloads'% tot)



'''
---stpip---
This file contains the code that go scrap the website

@R. Thomas
@Santiago, Chile
@2019
'''


##standard library
import requests

#local import
from bs4 import BeautifulSoup

def scrap(package):
    '''
    This function go scrap pepy.tech

    Parameters
    -----------
    package
            str, name of the pypi package

    Returns
    -------
    total
            int, total number of downloads, all time
    month
            int, number of downloads in last month
    day
            int, number of downloads in the last week
    last_date
            str, date of the last day the stat was computed
    last_date_down, 
            int, number of downloads during last_date day
    '''

    url = 'https://pepy.tech/project/' + package

    response = requests.get(url)
    soup = BeautifulSoup(response.content, 'html.parser')
    name_box = soup.find_all('table', attrs={'class': 'table'})

    a = [my_tag.text for my_tag in soup.find_all('table', attrs={'class':'table'})]
    counts = a[0].split()
    
    if counts[0] == 'Total':
        total = int(counts[2].replace(',', ''))
        month = int(counts[8].replace(',', ''))
        day = int(counts[14].replace(',', ''))

        last_days = a[1].split()
        last_date_down = last_days[3]
        last_date = last_days[2]

    else:
        total = 0
        month = 0
        day = 0

        last_days = 0
        last_date_down = '0 0 0'
        last_date = 0

    return total, month, day, last_date, last_date_down






__version__ = '19.3.2'
__place__ = 'Santiago, Chile'
__credits__ = "Romain Thomas"
__license__ = "GNU GPL v3"
__maintainer__ = "Romain Thomas"
__email__ = "the.spartan.proj@gmail.com"
__status__ = "released"
__website__ = "https://github.com/astrom-tom/stpip"



from setuptools import setup

__version__ = '19.3.3'
__credits__ = "Romain Thomas"
__license__ = "GNU GPL v3"
__maintainer__ = "Romain Thomas"
__email__ = "the.spartan.proj@gmail.com"
__status__ = "released"
__website__ = "https://github.com/astrom-tom/stpip"

setup(
   name = 'stpip',
   version = __version__,
   author = __credits__,
   packages = ['stpip'],
   entry_points = {'console_scripts': ['stpip = stpip.__main__:main',],},
   description = 'a pepy.tech web-scrapping for pypi download statistics',
   license = __license__,
   url = __website__,
   python_requires = '>=3.5',
   install_requires = [
       "requests >= 2.21.0",
       "bs4 >= 0.0.1"
   ],
   include_package_data=True,
)
